# Change History

## 2022.7.17

* Maintenance release with updates in test and dev dependencies as well as type and test fixes

## Older

### 2021.2.28 (0.0.3)

* Third release on PyPI:
    * added abstract setup tools install requires declarations
    * added SWID example (TODO)

### 2021.2.27 (0.0.2)

* Second release on PyPI:
    * better metadata
    * added CycloneDX dependency
    * added spdx-tools dependency (might go away soon)
    * added SPDX example in Tag/Value format
    * added more tests

### 2021.2.27 (0.0.1)

* First release on PyPI.
